#!/GPFS/zhangli_lab_permanent/zhuqingjie/env/py3_tf2/bin/python
'''
@Time    : 20/11/05 下午 01:57
@Author  : zhuqingjie 
@User    : zhu
@FileName: __init__.py.py
@Software: PyCharm
'''

__version__ = '0.10.0'

__doc__ = \
    '''
    An easy-to-use program for analyzing Drosophila Activity.
    '''
